<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="联机用户" prop="userName">
        <el-input
          v-model="queryParams.userName"
          placeholder="请输入联机用户"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="联机地址" prop="ip">
        <el-input
          v-model="queryParams.ip"
          placeholder="请输入联机地址"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="联机地点" prop="loginLocation">
        <el-input
          v-model="queryParams.loginLocation"
          placeholder="请输入联机地点"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
<!--      <el-form-item label="联机时间" prop="loginTime">-->
<!--        <el-date-picker clearable size="small"-->
<!--          v-model="queryParams.loginTime"-->
<!--          type="date"-->
<!--          value-format="yyyy-MM-dd"-->
<!--          placeholder="选择联机时间">-->
<!--        </el-date-picker>-->
<!--      </el-form-item>-->
      <el-form-item label="操作行为" prop="operation">
        <el-select v-model="queryParams.operation" placeholder="请选择操作行为" clearable size="small">
          <el-option
            v-for="dict in dict.type.DICT108"
            :key="dict.value"
            :label="dict.label"
            :value="dict.value"
          />
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['oa:equipmentLog:remove']"
        >删除</el-button>
      </el-col>
<!--      <el-col :span="1.5">-->
<!--        <el-button-->
<!--          type="warning"-->
<!--          plain-->
<!--          icon="el-icon-download"-->
<!--          size="mini"-->
<!--          @click="handleExport"-->
<!--          v-hasPermi="['oa:equipmentLog:export']"-->
<!--        >导出</el-button>-->
<!--      </el-col>-->
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="equipmentLogList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="序号" align="center" width="50">
        <template slot-scope="scope">
          <span>{{ scope.$index + (queryParams.pageNum - 1) * queryParams.pageSize + 1 }} </span>
        </template>
      </el-table-column>
      <el-table-column label="联机用户" align="center" prop="userName" />
      <el-table-column label="联机地址" align="center" prop="ip" />
      <el-table-column label="联机地点" align="center" prop="loginLocation" />
      <el-table-column label="联机状态" align="center">
        <template slot-scope="scope">
          <span v-if="scope.row.status === '0'">成功</span>
          <span v-if="scope.row.status === '1'">失败</span>
        </template>
      </el-table-column>
      <el-table-column label="操作行为" align="center" prop="operation_dictText" />
      <el-table-column label="联机时间" align="center" prop="loginTime" />
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />
  </div>
</template>

<script>
import { listEquipmentLog, getEquipmentLog, delEquipmentLog, addEquipmentLog, updateEquipmentLog } from "@/api/oa/equipmentLog";

export default {
  name: "EquipmentLog",
  dicts: ['DICT108'],
  data() {
    return {
      // 按钮loading
      buttonLoading: false,
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 设备联机日志表格数据
      equipmentLogList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        operation: undefined,
        userName: undefined,
        nickName: undefined,
        ip: undefined,
        loginLocation: undefined,
        status: undefined,
        loginTime: undefined
      }
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询设备联机日志列表 */
    getList() {
      this.loading = true;
      listEquipmentLog(this.queryParams).then(response => {
        this.equipmentLogList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: undefined,
        operation: undefined,
        userName: undefined,
        nickName: undefined,
        ip: undefined,
        loginLocation: undefined,
        status: "0",
        loginTime: undefined
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除设备联机日志编号为"' + ids + '"的数据项？').then(() => {
        this.loading = true;
        return delEquipmentLog(ids);
      }).then(() => {
        this.loading = false;
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).finally(() => {
        this.loading = false;
      });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('oa/equipmentLog/export', {
        ...this.queryParams
      }, `equipmentLog_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
